@@ -8,7 +8,8 @@ class ImproperlyConfigured(Exception):
 class UnknownLocaleError(Exception):
     def __init__(self, locale, obj):
         Exception.__init__(self,
-            'Unknown locale %s given for %r. Locale is not one of %r' % (
-                locale, obj, list(option(obj, 'locales'))
+            'Unknown locale %s given for instance of class %r. '
+            'Locale is not one of %r' % (
+                locale, obj.__class__, list(option(obj, 'locales'))
             )
         )
